#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Promote :
    def __init__( self):
        self.mailboxUid = None
        self.folder = None
        self.hsmId = None
        self.imapUid = None
        pass

class __PromoteSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = Promote()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        mailboxUidValue = value['mailboxUid']
        instance.mailboxUid = serder.STRING.parse(mailboxUidValue)
        folderValue = value['folder']
        instance.folder = serder.STRING.parse(folderValue)
        hsmIdValue = value['hsmId']
        instance.hsmId = serder.STRING.parse(hsmIdValue)
        imapUidValue = value['imapUid']
        instance.imapUid = serder.INT.parse(imapUidValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        mailboxUidValue = value.mailboxUid
        instance["mailboxUid"] = serder.STRING.encode(mailboxUidValue)
        folderValue = value.folder
        instance["folder"] = serder.STRING.encode(folderValue)
        hsmIdValue = value.hsmId
        instance["hsmId"] = serder.STRING.encode(hsmIdValue)
        imapUidValue = value.imapUid
        instance["imapUid"] = serder.INT.encode(imapUidValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class RetentionPolicy :
    def __init__( self):
        self.daily = None
        self.weekly = None
        self.monthly = None
        pass

class __RetentionPolicySerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = RetentionPolicy()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        dailyValue = value['daily']
        instance.daily = serder.INT.parse(dailyValue)
        weeklyValue = value['weekly']
        instance.weekly = serder.INT.parse(weeklyValue)
        monthlyValue = value['monthly']
        instance.monthly = serder.INT.parse(monthlyValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        dailyValue = value.daily
        instance["daily"] = serder.INT.encode(dailyValue)
        weeklyValue = value.weekly
        instance["weekly"] = serder.INT.encode(weeklyValue)
        monthlyValue = value.monthly
        instance["monthly"] = serder.INT.encode(monthlyValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class BaseDirEntry :
    def __init__( self):
        self.displayName = None
        self.entryUid = None
        self.accountType = None
        self.kind = None
        pass

class __BaseDirEntrySerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = BaseDirEntry()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        displayNameValue = value['displayName']
        instance.displayName = serder.STRING.parse(displayNameValue)
        entryUidValue = value['entryUid']
        instance.entryUid = serder.STRING.parse(entryUidValue)
        from netbluemind.directory.api.BaseDirEntryAccountType import BaseDirEntryAccountType
        from netbluemind.directory.api.BaseDirEntryAccountType import __BaseDirEntryAccountTypeSerDer__
        accountTypeValue = value['accountType']
        instance.accountType = __BaseDirEntryAccountTypeSerDer__().parse(accountTypeValue)
        from netbluemind.directory.api.BaseDirEntryKind import BaseDirEntryKind
        from netbluemind.directory.api.BaseDirEntryKind import __BaseDirEntryKindSerDer__
        kindValue = value['kind']
        instance.kind = __BaseDirEntryKindSerDer__().parse(kindValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        displayNameValue = value.displayName
        instance["displayName"] = serder.STRING.encode(displayNameValue)
        entryUidValue = value.entryUid
        instance["entryUid"] = serder.STRING.encode(entryUidValue)
        from netbluemind.directory.api.BaseDirEntryAccountType import BaseDirEntryAccountType
        from netbluemind.directory.api.BaseDirEntryAccountType import __BaseDirEntryAccountTypeSerDer__
        accountTypeValue = value.accountType
        instance["accountType"] = __BaseDirEntryAccountTypeSerDer__().encode(accountTypeValue)
        from netbluemind.directory.api.BaseDirEntryKind import BaseDirEntryKind
        from netbluemind.directory.api.BaseDirEntryKind import __BaseDirEntryKindSerDer__
        kindValue = value.kind
        instance["kind"] = __BaseDirEntryKindSerDer__().encode(kindValue)
        return instance




import base64
from base64 import b64decode
from base64 import b64encode
from  datetime import datetime

class ByteArraySerDer:

    @classmethod
    def parse(cls, value):
        if value == None:
            return None
        else:
            return b64decode(value)

    @classmethod
    def encode(cls, value):
        if value == None:
            return None
        else:
            return b64encode(value)

class STRING:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value

class STREAM:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value

class LONG:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value


class DOUBLE:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value


class INT:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value

class DATE:

    @classmethod
    def parse(cls, value):
        if value == None:
            return None
        else:
            return datetime.fromtimestamp(value/1000)

    @classmethod
    def encode(cls, value):
        if value == None:
            return None
        else:
            return int((value - datetime(1970, 1, 1)).total_seconds() * 1000)

class BOOLEAN:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value

class VOID:

    @classmethod
    def parse(cls, value):
        return value

    @classmethod
    def encode(cls, value):
        return value

class MapSerDer:
    def __init__(self, serder):
        self.serder = serder

    def parse(self, value):
        if value == None:
            return None

        ret = dict()
        for v in value.keys():
            ret[v] = self.serder.parse( value[v] )
        return ret


    def encode(self, value):
        if value == None:
            return None

        ret = dict()
        for v in value.keys():
            ret[v] = self.serder.encode( value[v] )
        return ret


class CollectionSerDer:
    def __init__(self, serder):
        self.serder = serder


    def parse(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append( self.serder.parse( v) )
        return ret

    def encode(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append( self.serder.encode( v) )
        return ret

class ListSerDer:
    def __init__(self, serder):
        self.serder = serder

    def parse(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append( self.serder.parse( v) )
        return ret

    def encode(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append( self.serder.encode( v) )
        return ret

class ArraySerDer:
    def __init__(self, serder):
        self.serder = serder

    def parse(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append( self.serder.parse( v) )
        return ret

    def encode(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append( self.serder.encode( v) )
        return ret


class SetSerDer:
    def __init__(self, serder):
        self.serder = serder

    def parse(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append( self.serder.parse( v) )
        return ret

    def encode(self, value):
        if value == None:
            return None

        ret = []
        for v in value:
            ret.append( self.serder.encode( v) )
        return ret



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IExternalSystem_VERSION = "3.1.42818"

class IExternalSystem(BaseEndpoint):
    def __init__(self, apiKey, url ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/system/external'

    def getLogo (self, systemIdentifier ):
        postUri = "/{systemIdentifier}/_logo";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{systemIdentifier}",systemIdentifier);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalSystem_VERSION}, data = __encoded__);
        return self.handleResult__(serder.ByteArraySerDer, response)
    def getExternalSystem (self, systemIdentifier ):
        postUri = "/{systemIdentifier}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{systemIdentifier}",systemIdentifier);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalSystem_VERSION}, data = __encoded__);
        from netbluemind.system.api.ExternalSystem import ExternalSystem
        from netbluemind.system.api.ExternalSystem import __ExternalSystemSerDer__
        return self.handleResult__(__ExternalSystemSerDer__(), response)
    def getExternalSystems (self):
        postUri = "";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IExternalSystem_VERSION}, data = __encoded__);
        from netbluemind.system.api.ExternalSystem import ExternalSystem
        from netbluemind.system.api.ExternalSystem import __ExternalSystemSerDer__
        return self.handleResult__(serder.ListSerDer(__ExternalSystemSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class MailFilter :
    def __init__( self):
        self.rules = None
        self.forwarding = None
        self.vacation = None
        pass

class __MailFilterSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = MailFilter()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.mailbox.api.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.MailFilterRule import __MailFilterRuleSerDer__
        rulesValue = value['rules']
        instance.rules = serder.ListSerDer(__MailFilterRuleSerDer__()).parse(rulesValue)
        from netbluemind.mailbox.api.MailFilterForwarding import MailFilterForwarding
        from netbluemind.mailbox.api.MailFilterForwarding import __MailFilterForwardingSerDer__
        forwardingValue = value['forwarding']
        instance.forwarding = __MailFilterForwardingSerDer__().parse(forwardingValue)
        from netbluemind.mailbox.api.MailFilterVacation import MailFilterVacation
        from netbluemind.mailbox.api.MailFilterVacation import __MailFilterVacationSerDer__
        vacationValue = value['vacation']
        instance.vacation = __MailFilterVacationSerDer__().parse(vacationValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.mailbox.api.MailFilterRule import MailFilterRule
        from netbluemind.mailbox.api.MailFilterRule import __MailFilterRuleSerDer__
        rulesValue = value.rules
        instance["rules"] = serder.ListSerDer(__MailFilterRuleSerDer__()).encode(rulesValue)
        from netbluemind.mailbox.api.MailFilterForwarding import MailFilterForwarding
        from netbluemind.mailbox.api.MailFilterForwarding import __MailFilterForwardingSerDer__
        forwardingValue = value.forwarding
        instance["forwarding"] = __MailFilterForwardingSerDer__().encode(forwardingValue)
        from netbluemind.mailbox.api.MailFilterVacation import MailFilterVacation
        from netbluemind.mailbox.api.MailFilterVacation import __MailFilterVacationSerDer__
        vacationValue = value.vacation
        instance["vacation"] = __MailFilterVacationSerDer__().encode(vacationValue)
        return instance

